copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
JsonValueRef copyWith({int /*U32*/ ? index_}) =>
JsonValueRef(index_: index_ ?? this.index_);
Returns a new instance by overriding the values passed as arguments
JsonValueRef copyWith({int /*U32*/ ? index_}) =>
JsonValueRef(index_: index_ ?? this.index_);