copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
StartLength copyWith({int /*U32*/ ? start, int /*U32*/ ? length}) =>
StartLength(start: start ?? this.start, length: length ?? this.length);
Returns a new instance by overriding the values passed as arguments
StartLength copyWith({int /*U32*/ ? start, int /*U32*/ ? length}) =>
StartLength(start: start ?? this.start, length: length ?? this.length);