copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
UndoManagerRef copyWith({int /*U32*/ ? ref}) =>
UndoManagerRef(ref: ref ?? this.ref);
Returns a new instance by overriding the values passed as arguments
UndoManagerRef copyWith({int /*U32*/ ? ref}) =>
UndoManagerRef(ref: ref ?? this.ref);