copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
WriteTransaction copyWith({int /*U32*/ ? ref}) =>
WriteTransaction(ref: ref ?? this.ref);
Returns a new instance by overriding the values passed as arguments
WriteTransaction copyWith({int /*U32*/ ? ref}) =>
WriteTransaction(ref: ref ?? this.ref);