copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
YXmlElement copyWith({int /*U32*/ ? ref}) =>
YXmlElement(ref: ref ?? this.ref);
Returns a new instance by overriding the values passed as arguments
YXmlElement copyWith({int /*U32*/ ? ref}) =>
YXmlElement(ref: ref ?? this.ref);