copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
YXmlFragment copyWith({int /*U32*/ ? ref}) =>
YXmlFragment(ref: ref ?? this.ref);
Returns a new instance by overriding the values passed as arguments
YXmlFragment copyWith({int /*U32*/ ? ref}) =>
YXmlFragment(ref: ref ?? this.ref);